==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TokenCredentialsPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of the credentials that can be used for authenticating the token.
 * @property certificates
 * @property passwords
 */
public data class TokenCredentialsPropertiesArgs(
    public val certificates: Output<List<TokenCertificateArgs>>? = null,
    public val passwords: Output<List<TokenPasswordArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs.builder()
            .certificates(
                certificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .passwords(
                passwords?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TokenCredentialsPropertiesArgs].
 */
@PulumiTagMarker
public class TokenCredentialsPropertiesArgsBuilder internal constructor() {
    private var certificates: Output<List<TokenCertificateArgs>>? = null

    private var passwords: Output<List<TokenPasswordArgs>>? = null

    /**
     * @param value
     */
    @JvmName("ltjqafurqmehqxsx")
    public suspend fun certificates(`value`: Output<List<TokenCertificateArgs>>) {
        this.certificates = value
    }

    @JvmName("eegykhdklpiscdjd")
    public suspend fun certificates(vararg values: Output<TokenCertificateArgs>) {
        this.certificates = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ccdvqvtfxjxerlcn")
    public suspend fun certificates(values: List<Output<TokenCertificateArgs>>) {
        this.certificates = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pfnwjqywllebbupk")
    public suspend fun passwords(`value`: Output<List<TokenPasswordArgs>>) {
        this.passwords = value
    }

    @JvmName("smppklxvqdkefhqs")
    public suspend fun passwords(vararg values: Output<TokenPasswordArgs>) {
        this.passwords = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("uwkivhgcccqgvwyi")
    public suspend fun passwords(values: List<Output<TokenPasswordArgs>>) {
        this.passwords = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yhqurysxdgnwpsny")
    public suspend fun certificates(`value`: List<TokenCertificateArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qytcogrcbydlmlxs")
    public suspend fun certificates(argument: List<suspend TokenCertificateArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TokenCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gpcejhlovepwtuwq")
    public suspend fun certificates(vararg argument: suspend TokenCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TokenCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ysnredrcqsmohetg")
    public suspend fun certificates(argument: suspend TokenCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenCertificateArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param values
     */
    @JvmName("mevtxvqpetndjedq")
    public suspend fun certificates(vararg values: TokenCertificateArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificates = mapped
    }

    /**
     * @param value
     */
    @JvmName("gtlxbpdgarmyrhle")
    public suspend fun passwords(`value`: List<TokenPasswordArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bmnvldrwfjrinsmf")
    public suspend fun passwords(argument: List<suspend TokenPasswordArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TokenPasswordArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("aqktmyofsmanwaes")
    public suspend fun passwords(vararg argument: suspend TokenPasswordArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TokenPasswordArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tngkxabcdyuafcws")
    public suspend fun passwords(argument: suspend TokenPasswordArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenPasswordArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param values
     */
    @JvmName("ajwagyuglhlbscnt")
    public suspend fun passwords(vararg values: TokenPasswordArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    internal fun build(): TokenCredentialsPropertiesArgs = TokenCredentialsPropertiesArgs(
        certificates = certificates,
        passwords = passwords,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TokenCredentialsPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of the credentials that can be used for authenticating the token.
 * @property certificates
 * @property passwords
 */
public data class TokenCredentialsPropertiesArgs(
    public val certificates: Output<List<TokenCertificateArgs>>? = null,
    public val passwords: Output<List<TokenPasswordArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TokenCredentialsPropertiesArgs.builder()
            .certificates(
                certificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .passwords(
                passwords?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TokenCredentialsPropertiesArgs].
 */
@PulumiTagMarker
public class TokenCredentialsPropertiesArgsBuilder internal constructor() {
    private var certificates: Output<List<TokenCertificateArgs>>? = null

    private var passwords: Output<List<TokenPasswordArgs>>? = null

    /**
     * @param value
     */
    @JvmName("jnwlpntlbgigbqpe")
    public suspend fun certificates(`value`: Output<List<TokenCertificateArgs>>) {
        this.certificates = value
    }

    @JvmName("vnshdjvxfhjaprnl")
    public suspend fun certificates(vararg values: Output<TokenCertificateArgs>) {
        this.certificates = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("sduccnuvdmrocrsl")
    public suspend fun certificates(values: List<Output<TokenCertificateArgs>>) {
        this.certificates = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("jcqjlwuqvsbiuwpq")
    public suspend fun passwords(`value`: Output<List<TokenPasswordArgs>>) {
        this.passwords = value
    }

    @JvmName("ilahgwywuplfbwkc")
    public suspend fun passwords(vararg values: Output<TokenPasswordArgs>) {
        this.passwords = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("pjcxphvpicieprrx")
    public suspend fun passwords(values: List<Output<TokenPasswordArgs>>) {
        this.passwords = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("tnsfcloewljthunl")
    public suspend fun certificates(`value`: List<TokenCertificateArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wmitvyptchrnaiea")
    public suspend fun certificates(argument: List<suspend TokenCertificateArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TokenCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ulvnathfbacugnbx")
    public suspend fun certificates(vararg argument: suspend TokenCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TokenCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kaiyuyoynebodogm")
    public suspend fun certificates(argument: suspend TokenCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenCertificateArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.certificates = mapped
    }

    /**
     * @param values
     */
    @JvmName("buhdqeyubhsbecyo")
    public suspend fun certificates(vararg values: TokenCertificateArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificates = mapped
    }

    /**
     * @param value
     */
    @JvmName("cikojquhidaidhbh")
    public suspend fun passwords(`value`: List<TokenPasswordArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mlruninpqcrkttcl")
    public suspend fun passwords(argument: List<suspend TokenPasswordArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TokenPasswordArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ghjfmwlicxrflftl")
    public suspend fun passwords(vararg argument: suspend TokenPasswordArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TokenPasswordArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mhdlwgggjuwtuyub")
    public suspend fun passwords(argument: suspend TokenPasswordArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenPasswordArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.passwords = mapped
    }

    /**
     * @param values
     */
    @JvmName("typfxujgmqbymbnr")
    public suspend fun passwords(vararg values: TokenPasswordArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    internal fun build(): TokenCredentialsPropertiesArgs = TokenCredentialsPropertiesArgs(
        certificates = certificates,
        passwords = passwords,
    )
}
